# shelter: parts-v1

- Power
    - 12 V DC SMPS power supply (5–10 A) or 12 V battery
    - Inline fuse holder + 10 A blade fuse
    - DC barrel jack / terminal block connectors
    - Wires 1.0–1.5 mm² copper (red/black)
- Control & Logic
    - Arduino Uno / Nano (Nano is cheaper, smaller, widely available in Iran)
    - Relay module (1-channel, 10 A, opto-isolated) for heater switching
    - W1209 digital thermostat module (optional as backup safety control)
- Heating
    - PTC ceramic heater 12 V 60–100 W
    - Thermal fuse 128–133 °C (mounted directly on heater surface)
    - Small 12 V fan (80 mm) with grill (for circulation, optional)
- Sensors
    - DS18B20 waterproof temperature sensor (or DHT22 if humidity also needed)
    - NTC thermistor (10 kΩ) as backup probe
- Safety
    - Portable RCD/ELCB plug (if running from AC)
    - Heat-shrink tubing + crimp connectors
    - Cable glands (PG7/PG9) for enclosure wiring
